# define name of config file
CONFIG_FILE = './config.ini'

# defne MariaDB table to write to or rebuild from
MDB_DATA_TABLE_NAME = 'mdb_test_table1'
MDB_DATA_IDS = ['test_name', 'test_value_i', 'test_value_f']
MDB_DATA_TYPES = ['VARCHAR(255)', 'INT', 'FLOAT']

